.. pyndl documentation master file, created by
   sphinx-quickstart on Thu Jan 26 17:28:31 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   installation
   ndl
   examples
   pyndl
   development
   misc
   about
